//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI.RDF;

import ch.hearc.I04_05s08.GUI.DialogBox;
import javax.swing.*;
import java.awt.*;

/**
 *	A dialog box for RDFS node
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public class RdfDialog extends DialogBox
{	
	/**
	 *	Text fields
	 */
	private JTextField[] textfields;
	
	/**
	 *	Build the dialog (and show it)
	 *
	 *	@param node		the node to edit
	 *	@param graph		the parent graph
	 */
	public RdfDialog(RdfNode node, RdfGraph graph)
	{
		super("RDF", node, graph);
		
		JButton cancel = getCancelButton();
		RdfDialogCancelListener rdcl = new RdfDialogCancelListener((DialogBox)this);
		cancel.addActionListener(rdcl);
		getModifyButton().addActionListener(new RdfDialogModifyListener((DialogBox)this));
		
		textfields = new JTextField[]{
			new JTextField(30),
			new JTextField(30)
		};
		
		JPanel formpanel = getTopPanel();
		JPanel labels = new JPanel();
		JPanel fields = new JPanel();
		
		Box hbox = Box.createHorizontalBox();
		
		GridLayout gridlabels = new GridLayout(2,1);
		GridLayout gridfields = new GridLayout(2,1);
		
		//formpanel.setLayout(grid);
		labels.setLayout(gridlabels);
		fields.setLayout(gridfields);
		
		if(((RdfNode)getElement()).getInstanceOfClass().isInstance())
		{
			labels.add(new JLabel("Resource : "));
			fields.add(textfields[0]);
		}
		
		if(((RdfNode)getElement()).getInstanceOfClass().isLiteral())
			labels.add(new JLabel("Value : "));
		else
			labels.add(new JLabel("URL : "));
			
		fields.add(textfields[1]);
		
		
		hbox.add(labels);
		hbox.add(fields);
		
		formpanel.add(hbox);
		
		clear();
		pack();
		setVisible(true);
		
	}
	
	/**
	 *	Clear the values
	 */
	public void clear()
	{
		textfields[0].setText(
			(((RdfNode)getElement()).getInstanceOfClass().getName() != null)
			? ((RdfNode)getElement()).getInstanceOfClass().getName()
			: ""
		);
		
		textfields[0].setEditable(false);
		
		
		textfields[1].setText(
			(((RdfNode)getElement()).getInstanceOfClass().getValue() != null)
			? ((RdfNode)getElement()).getInstanceOfClass().getValue()
			: ""
		);
		/*
		textfields[2].setText(
			(((RdfsNode)getElement()).getInstanceOfClass().getComment() != null)
			? ((RdfsNode)getElement()).getInstanceOfClass().getComment()
			: ""
		);*/
	}
	
	/**
	 *	Apply the values
	 */
	public void apply()
	{
		/*((RdfsNode)getElement()).setName(textfields[0].getText());
		((RdfsNode)getElement()).setLabel(textfields[1].getText());
		((RdfsNode)getElement()).setComment(textfields[2].getText());
		*/
		
		if(!textfields[1].getText().equals(""))
			((RdfNode)getElement()).getInstanceOfClass().setValue(textfields[1].getText());
		
		((RdfNode)getElement()).update();
		getGraph().redraw();
	}
}
