//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI.RDF;

import ch.hearc.I04_05s08.GUI.Graph.*;
import ch.hearc.I04_05s08.Ontology.RDF.InstanceOfClass;

/**
 *	A node for RDFS graph
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public abstract class RdfNode extends Node
{
	/**
	 *	RFDS Resource
	 */
	private InstanceOfClass ioc;
	
	/**
	 *	Build a rdf node
	 *
	 *	@param ioc		the instance of class
	 */
	public RdfNode(InstanceOfClass ioc)
	{
		super((ioc.isInstance() ? ioc.getShortValue() : (ioc.isLiteral() ? ioc.getValue() : ioc.getShortName())));
		
		this.ioc= ioc;
	}
	
	/**
	 *	Build a copy of a rdf node
	 *
	 *	@param n		the instance of class
	 */
	public RdfNode(RdfNode n)
	{
		super(n);
		setTitle((n.ioc.isInstance() ? n.ioc.getShortValue() : (n.ioc.isLiteral() ? n.ioc.getValue() : n.ioc.getShortName())));
		
		ioc= (InstanceOfClass)n.ioc.clone();
	}

	/**
	 *	Get the intance of Class
	 *
	 *	@return instance of class
	 */
	public InstanceOfClass getInstanceOfClass()
	{
		return ioc;
	}
	
	/**
	 *	Set the value of the instance fo class
	 *
	 *	@param value			instance of class value (literal)
	 */
	public void setValue(String value)
	{
		if(ioc.isLiteral())
		{
			ioc.setValue(value);
			setTitle(value);
		}
	}
	
	/**
	 *	Update the node
	 */
	public void update()
	{
		setTitle((ioc.isInstance() ? ioc.getShortValue() : (ioc.isLiteral() ? ioc.getValue() : ioc.getShortName())));
		if(getGraph() != null)
			((RdfGraph)getGraph()).update();
		super.update();
	}
}
