//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI.RDF;

import ch.hearc.I04_05s08.GUI.SimpleFileFilter;
import ch.hearc.I04_05s08.Ontology.OntManager;
import ch.hearc.I04_05s08.Ontology.RDFS.RdfsFile;
import ch.hearc.I04_05s08.Ontology.RDF.RdfFile;
import javax.swing.*;
import java.awt.*;

/**
 *	The dialogbox for Rdf File (extended menu)
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public class RdfOpenFileDialog extends RdfFileDialog
{	
	/**
	 *	The file name
	 */
	private JTextField filename;
	
	/**
	 *	A File chooser
	 */
	private JFileChooser jfc;
	
	/**
	 *	Build a rdf file dialog
	 *
	 *	@param manager		the RDF manager
	 */
	public RdfOpenFileDialog(RdfGraphManager manager)
	{
		super("Open RDF file", manager);
		
		JPanel top = super.getTopPanel();
		
		jfc = new JFileChooser();
		SimpleFileFilter filter = new SimpleFileFilter();
		filter.addExtension("rdf");
		filter.addExtension("xml");
		filter.setDescription("RDF File");
		jfc.setFileFilter(filter);
		
		filename = new JTextField(chooseRdf(),30);
		
		top.add(new JLabel("RDF"));
		top.add(filename);

		pack();
		centerScreen();
		setVisible(true);
	}
	
	/**
	 *	Choose a RDF File
	 *
	 *	@return the path of the file
	 */
	public String chooseRdf()
	{
		int returnVal = jfc.showOpenDialog(getManager().getMainFrame());
		
		if(returnVal == JFileChooser.APPROVE_OPTION)
		{
			return jfc.getSelectedFile().getPath();
		}
		else
		{
			return "";
		}
	}
	
	/**
	 *	Apply the changes
	 */
	public void apply()
	{
		RdfsFile[] files = new RdfsFile[getListModel().getSize()];
		for(int i=0; i<files.length; i++)
		{
			files[i] = OntManager.openRdfs(getListModel().getElementAt(i).toString());	
		}
		
		if(!filename.getText().equals(""))
			getManager().loadGraph(OntManager.openRdf(filename.getText(),files));
		else
			getManager().loadGraph(new RdfFile("",files));
		close();
	}
}