//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI.RDF;

import ch.hearc.I04_05s08.GUI.*;
import ch.hearc.I04_05s08.GUI.Graph.*;
import ch.hearc.I04_05s08.Ontology.*;
import ch.hearc.I04_05s08.Ontology.RDF.*;
import javax.swing.*;
import java.awt.geom.*;

/**
 *	A Rdfs Tab
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public class RdfTab extends Tab
{
	/**
	 *	Build a new tab
	 *
	 *	@param file			the RDF Schema
	 *	@param mainframe	the main frame
	 */
	public RdfTab(RdfFile file, MainApplication mainframe)
	{
		super(file, mainframe.getRdfManager());
		
		// text pane
		//JTextPane tp = new JTextPane();
		SourcePane tp = new SourcePane();
		JTabbedPane tpg = new JTabbedPane(JTabbedPane.BOTTOM);
		
		tp.setEditable(false);
		
		RdfGraph graph = new RdfGraph(file, tp);
		
		GraphListener listener = new GraphListener(graph);
		
		ToolBars tb = new ToolBars();
		
		RdfToolBar rtb = (RdfToolBar)tb.getRDF(file.getRdfs(), graph);
		// important for the colors
		setGraph(graph);
		
		tpg.add("Graph" ,new JScrollPane(graph));
		tpg.add("Source", new JScrollPane(tp));
		
		JSplitPane sp = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT, rtb, tpg);
		sp.setOneTouchExpandable(true);
		
		add(sp);
	}
	
	/**
	 *	Init the graph
	 */
	public void init()
	{
		InstanceOfClass[] c = ((RdfFile)getFile()).getClasses();
		InstanceOfProperty[] p = ((RdfFile)getFile()).getProperties();
		
		// Class
		
		RdfNode n;
		RdfNode to;
		RdfArrow a;
		
		int counter=0;
		
		for(int i=0; i<c.length; i++)
		{
			if(!c[i].isLiteral())
			{
				n = (RdfNode)new RdfResource(c[i]);
				n.setPos(new Point2D.Double(0, counter*40));
				counter++;
				
				getGraph().add(n);
			}
		}
		
		// Property
		
		counter = 0;
		
		for(int i=0; i<p.length; i++)
		{
			n = ((RdfGraph)getGraph()).getNode(p[i].getPropertyOf());
			
			if(n == null)
			{
				System.out.println(n);
				break;
			}
			
			if(p[i].getProperty().isLiteral())
			{
				to = (RdfNode)new RdfLiteral(p[i].getProperty());
				to.setPos(new Point2D.Double(200, counter*40));
				counter++;
				getGraph().add(to);
			}
			else
			{
				to = ((RdfGraph)getGraph()).getNode(p[i].getProperty());
			}
			
			a = ((RdfGraph)getGraph()).getArrow(p[i]);
			a.setNodes(n,to);
			
			getGraph().add(a);
		}
	}
}
