//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI.RDF;

import java.awt.*;
import javax.swing.*;
import javax.swing.tree.*;
import ch.hearc.I04_05s08.Ontology.RDFS.*;
import ch.hearc.I04_05s08.Ontology.RDF.*;
import ch.hearc.I04_05s08.GUI.*;

/**
 *	Abstract toolbar
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public class RdfToolBar extends ToolBar
{
	/**
	 *	Known RDF Schemas
	 */
	private RdfsFile[] rdfs;
	
	/**
	 *	The graph
	 */
	private RdfGraph graph;
	
	/**
	 *	Tree
	 */
	private JTree tree;
	
	//	Icons for tree node
	/**
	 *	Node icon
	 */
	private Icon nodeIcon;
	
	/**
	 *	Arc icon
	 */
	private Icon arcIcon;
	
	/**
	 *	Literal icon
	 */
	private Icon literalIcon;
	
	/**
	 *	Literal (that isn't a class)
	 */
	private static String xstring = "http://www.w3.org/2000/10/XMLSchema#string";
	
	/**
	 *	Build the toolbar
	 *
	 *	@param rdfs		known RDF Schemas
	 */
	public RdfToolBar(RdfsFile[] rdfs, RdfGraph graph)
	{
		super();
		
		this.rdfs = rdfs;
		this.graph = graph;
		
		// disable flow layout
		setLayout(new BorderLayout());
		
		// build the icons
		nodeIcon = (Icon)(new ImageIcon("img/node.png"));
		arcIcon = (Icon)(new ImageIcon("img/arc.png"));
		literalIcon = (Icon)(new ImageIcon("img/literal.png"));
		
		initTree();
	}
	
	/**
	 *	Build the toolbar (without any rdfs)
	 */
	public RdfToolBar(RdfGraph graph)
	{
		this(null, graph);
	}
	
	/**
	 *	Build the treenode
	 */
	private void initTree()
	{		
		RdfTreeNode root = new RdfTreeNode("RDF");
		
		InstanceOfClass literal = new InstanceOfClass();
		literal.setValue("text");
		
		RdfTreeLeaf[] base = new RdfTreeLeaf[]{
			new RdfTreeLeaf(
				new InstanceOfClass(
					"http://www.example.org/URL"
				), nodeIcon
			), // URL
			new RdfTreeLeaf(
				literal
				, literalIcon
			), // Literal
			new RdfTreeLeaf(
				new InstanceOfProperty(
					"http://www.example.org/arc"
				)
				, arcIcon
			) // Arc
		};
		
		root.add(base);
		
		//--
		
		if(rdfs != null && rdfs.length>0)
		{
			RdfTreeNode[] rdfsnode = new RdfTreeNode[rdfs.length];
			
			RdfTreeLeaf[] nclasses;
			RdfTreeLeaf[] nprops;
			
			RdfsClass[] rclasses;
			RdfsProperty[] rprops;
			
			Color[] c = new Color[2];
			
			float r;
			float g;
			float b;
			
			for(int i=0; i<rdfs.length; i++)
			{
				r = (float)(Math.random()/4.);
				g = (float)(Math.random()/4.);
				b = (float)(Math.random()/4.);
				
				c[0] = new Color(
					r + .75f,
					g + .75f,
					b + .75f
				);
				
				c[1] = new Color(
					r,g,b
				);
				
				graph.addColor(c);
				
				rdfsnode[i] = new RdfTreeNode(rdfs[i].getName());
				
				rclasses = rdfs[i].getClasses();
				rprops = rdfs[i].getProperties();
				
				nclasses = new RdfTreeLeaf[rclasses.length];
				nprops = new RdfTreeLeaf[rprops.length];
				
				for(int j=0; j<nclasses.length; j++)
				{
					if(!rclasses[j].getName().equals(xstring))
					{
						nclasses[j] = new RdfTreeLeaf(new InstanceOfClass(rclasses[j],"http://www.example.org/"), nodeIcon);
						nclasses[j].setBackgroundColor(c[0]);
						nclasses[j].setForegroundColor(c[1]);
					}
				}
				
				for(int j=0; j<nprops.length; j++)
				{
					nprops[j] = new RdfTreeLeaf(new InstanceOfProperty(rprops[j]), arcIcon);
					nprops[j].setBackgroundColor(c[0]);
					nprops[j].setForegroundColor(c[1]);
				}
				
				rdfsnode[i].add(nclasses);
				rdfsnode[i].add(nprops);
				
				root.add(rdfsnode[i]);
			}
		}
		
		// tree
		tree = new JTree(root);
		// add the listener
		tree.addTreeSelectionListener(new RdfTreeSelectionListener(tree, graph));
		graph.setTree(tree);
		
		RdfTreeCellRenderer renderer = new RdfTreeCellRenderer();
		renderer.setOpenIcon(null);
		renderer.setClosedIcon(null);
		//renderer.setLeafIcon(null);
		
		tree.setCellRenderer(renderer);
		
		add(new JScrollPane(tree));
	}
}
