//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI.RDF;

import java.awt.*;
import javax.swing.*;
import javax.swing.tree.*;
import ch.hearc.I04_05s08.Ontology.RDFS.*;
import ch.hearc.I04_05s08.GUI.*;

/**
 *	Abstract toolbar
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public class RdfTreeCellRenderer extends DefaultTreeCellRenderer
{	
	/**
	 *	Build the icons
	 */
	public RdfTreeCellRenderer()
	{
		super();
	}
	
	/**
	 *	Configure the component of the JTree, add custom icons
	 *
	 *	@param tree			the tree
	 *	@param value			current node
	 *	@param sel			if selected
	 *	@param expanded		if open
	 *	@param leaf			if the node is a leaf
	 *	@param row			position
	 *	@param hasFocus		if selected
	 *	@return 				the Component
	 */
	public Component getTreeCellRendererComponent(
		JTree tree,
		Object value,
		boolean sel,
		boolean expanded,
		boolean leaf,
		int row,
		boolean hasFocus)
	{
		super.getTreeCellRendererComponent(tree,value,sel,expanded,leaf,row,hasFocus);
		
		if(value instanceof RdfTreeLeaf)
		{
			setIcon(((RdfTreeLeaf)value).getIcon());
			setBackgroundNonSelectionColor(((RdfTreeLeaf)value).getBackgroundColor());
			setTextNonSelectionColor(((RdfTreeLeaf)value).getForegroundColor());
		}
		else
		{
			setBackgroundNonSelectionColor(Color.white);
			setTextNonSelectionColor(Color.black);
		}
		
		if(value instanceof RdfTreeNode)
		{
			setToolTipText(((RdfTreeNode)value).getHelptext());
		}
		
		return this;
	}
}
