//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI.RDF;

import javax.swing.tree.*;

/**
 *	A node of the RDF Toolbar
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public class RdfTreeNode extends DefaultMutableTreeNode
{	
	/**
	 *	Help text of the node
	 */
	private String help;
	
	/**
	 *	Init the tree node
	 *
	 *	@param title		the title of the node
	 *	@param help		help text
	 */
	public RdfTreeNode(String title, String help)
	{
		super(title);
		
		this.help = help;
	}
	
	/**
	 *	Init the tree node
	 *
	 *	@param title		the title of the node
	 */
	public RdfTreeNode(String title)
	{
		this(title, null);
	}
	
	/**
	 *	Add childs
	 *
	 *	@param newChilds	add nodes
	 */
	public void add(MutableTreeNode[] newChilds)
	{		
		for(int i=0; i<newChilds.length; i++)
		{
			if(newChilds[i] != null)
				add(newChilds[i]);
		}
	}
	
	/**
	 *	Get help text
	 *
	 *	@return help text
	 */
	public String getHelptext()
	{
		return help;
	}
}
