//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI.RDFS;

import ch.hearc.I04_05s08.Ontology.RDFS.*;
import java.awt.*;
import java.awt.geom.*;

/**
 *	Node for a RDFS Class
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public class RdfsClassNode extends RdfsNode
{
	/**
	 *	Init the class node
	 *
	 *	@param c		the rdfs class attached
	 */
	public RdfsClassNode(RdfsClass c)
	{
		super(c);
		
		Dimension2D padding = getPadding();
		padding.setSize(getPadding().getWidth(), getPadding().getHeight()*3);
		setPadding(padding);
	}
	
	/**
	 *	Init the class node
	 *
	 *	@param c		the rdfs class attached
	 */
	public RdfsClassNode(RdfsClassNode c)
	{
		this((RdfsClass)c.getResource().clone());
		
		setPos(new Point2D.Double(c.getBounds().getX(), c.getBounds().getY()));
	}
	
	/**
	 *	Clone the class node
	 *
	 *	@return the clone
	 */
	public Object clone()
	{
		return new RdfsClassNode(this);
	}
	
	/**
	 *	Draw the Class
	 *
	 *	@param g2d	Graphic context
	 */
	public void draw(Graphics2D g2d)
	{		
		super.draw(g2d);
		
		Rectangle2D  rectangle = getBounds();
		
		Line2D line = new Line2D.Double(
			rectangle.getX(),rectangle.getY() + rectangle.getHeight()/3.,
			rectangle.getX()+rectangle.getWidth(),rectangle.getY() + rectangle.getHeight()/3.
		);
		
		g2d.draw(line);
		
		line = new Line2D.Double(
			rectangle.getX(),rectangle.getY() + 2*rectangle.getHeight()/3.,
			rectangle.getX()+rectangle.getWidth(),rectangle.getY() + 2*rectangle.getHeight()/3.
		);
		
		g2d.draw(line);
	}
	
	/**
	 *	Draw the title's class
	 *
	 *	@param g2d	Graphic context
	 */
	public void drawTitle(Graphics2D g2d)
	{
		Rectangle2D  rectangle = getBounds();
		
		g2d.drawString(
			getTitle(),
			(int)(rectangle.getX() + getPadding().getWidth()),
			(int)(rectangle.getCenterY() - 2*rectangle.getHeight()/6. + g2d.getFontMetrics().getHeight()/4.)
		);
	}
}
