//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI.RDFS;

import ch.hearc.I04_05s08.GUI.DialogBox;
import javax.swing.*;
import java.awt.*;

/**
 *	A dialog box for RDFS node
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public class RdfsDialog extends DialogBox
{	
	/**
	 *	Text fields
	 */
	private JTextField[] textfields;
	
	/**
	 *	Build the dialog (and show it)
	 *
	 *	@param node		the node to edit
	 *	@param graph		the parent graph
	 */
	public RdfsDialog(RdfsNode node, RdfsGraph graph)
	{
		super("RDFS", node, graph);
		
		JButton cancel = getCancelButton();
		RdfsDialogCancelListener rdcl = new RdfsDialogCancelListener(this);
		cancel.addActionListener(rdcl);
		getModifyButton().addActionListener(new RdfsDialogModifyListener(this));
		
		textfields = new JTextField[]{
			new JTextField(30),
			new JTextField(30),
			new JTextField(30)
		};
		
		JPanel formpanel = getTopPanel();
		JPanel labels = new JPanel();
		JPanel fields = new JPanel();
		
		Box hbox = Box.createHorizontalBox();
		
		GridLayout gridlabels = new GridLayout(3,1);
		GridLayout gridfields = new GridLayout(3,1);
		
		//formpanel.setLayout(grid);
		labels.setLayout(gridlabels);
		fields.setLayout(gridfields);
		
		labels.add(new JLabel("URL : "));
		fields.add(textfields[0]);
		
		labels.add(new JLabel("Label : "));
		fields.add(textfields[1]);
		
		labels.add(new JLabel("Comment : "));
		fields.add(textfields[2]);
		
		hbox.add(labels);
		hbox.add(fields);
		
		formpanel.add(hbox);
		
		clear();
		pack();
		setVisible(true);
	}
	
	/**
	 *	Clear the values
	 */
	public void clear()
	{
		textfields[0].setText(
			(((RdfsNode)getElement()).getResource().getName() != null)
			? ((RdfsNode)getElement()).getResource().getName()
			: ""
		);
		
		textfields[1].setText(
			(((RdfsNode)getElement()).getResource().getLabel() != null)
			? ((RdfsNode)getElement()).getResource().getLabel()
			: ""
		);
		
		textfields[2].setText(
			(((RdfsNode)getElement()).getResource().getComment() != null)
			? ((RdfsNode)getElement()).getResource().getComment()
			: ""
		);
	}
	
	/**
	 *	Apply the values
	 */
	public void apply()
	{
		((RdfsNode)getElement()).setName(textfields[0].getText());
		((RdfsNode)getElement()).setLabel(textfields[1].getText());
		((RdfsNode)getElement()).setComment(textfields[2].getText());
		
		((RdfsNode)getElement()).update();
		getGraph().redraw();
	}
}
