//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI.RDFS;

import ch.hearc.I04_05s08.GUI.*;
import ch.hearc.I04_05s08.GUI.Graph.*;
import ch.hearc.I04_05s08.Ontology.*;
import ch.hearc.I04_05s08.Ontology.RDFS.*;
import javax.swing.*;
import java.awt.geom.*;

/**
 *	A Rdfs Tab
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public class RdfsTab extends Tab
{
	/**
	 *	Build a new tab
	 *
	 *	@param file			the RDF Schema
	 *	@param mainframe	the main frame
	 */
	public RdfsTab(RdfsFile file, MainApplication mainframe)
	{
		super(file, mainframe.getRdfsManager());
		
		// text pane
		SourcePane tp = new SourcePane();
		JTabbedPane tpg = new JTabbedPane(JTabbedPane.BOTTOM);
		
		tp.setEditable(false);
		
		RdfsGraph graph = new RdfsGraph(file, tp);
		setGraph(graph);
		
		GraphListener listener = new GraphListener(graph);
		
		ToolBars tb = new ToolBars();
		
		RdfsToolBar rtb = (RdfsToolBar)tb.getRDFS();
		RdfsToolButtonListener rtbl = new RdfsToolButtonListener(graph);
		
		JButton[] btns = rtb.getButtons();
		for(int i=0; i<btns.length; i++)
		{
			btns[i].addActionListener(rtbl);
		}
		
		tpg.add("Graph" ,new JScrollPane(graph));
		tpg.add("Source", new JScrollPane(tp));
		
		JSplitPane sp = new JSplitPane(JSplitPane.HORIZONTAL_SPLIT, rtb, tpg);
		sp.setOneTouchExpandable(true);
		
		add(sp);
	}
	
	/**
	 *	Init the graph
	 */
	public void init()
	{
		RdfsClass[] c = ((RdfsFile)getFile()).getClasses();
		RdfsProperty[] p = ((RdfsFile)getFile()).getProperties();
		
		RdfsResource[] extend;
		RdfsClass[] domain;
		RdfsClass[] range;
		
		// Class
		
		for(int i=0; i<c.length; i++)
		{
			RdfsClassNode n = new RdfsClassNode(c[i]);
			getGraph().add(n);
			
			n.setPos(new Point2D.Double(0, i*40));
		}
		
		for(int i=0; i<c.length; i++)
		{
			extend = c[i].getSupClasses();
			
			for(int j=0; j<extend.length; j++)
			{
				getGraph().add(
					new RdfsExtend(
						((RdfsGraph)getGraph()).getNode(c[i]),
						((RdfsGraph)getGraph()).getNode(extend[j])
					)
				);
			}
		}
		
		// Property
		
		for(int i=0; i<p.length; i++)
		{
			RdfsPropertyNode n = new RdfsPropertyNode(p[i]);
			getGraph().add(n);
			
			n.setPos(new Point2D.Double(200, i*40));
		}
		
		for(int i=0; i<p.length; i++)
		{
			extend = p[i].getSupProperties();
			
			for(int j=0; j<extend.length; j++)
			{
				getGraph().add(
					new RdfsExtend(
						((RdfsGraph)getGraph()).getNode(p[i]),
						((RdfsGraph)getGraph()).getNode(extend[j])
					)
				);
			}
			
			domain = p[i].getDomain();
			
			for(int j=0; j<domain.length; j++)
			{
				getGraph().add(
					new RdfsDomain(
						((RdfsGraph)getGraph()).getNode(domain[j]),
						((RdfsGraph)getGraph()).getNode(p[i])
					)
				);
			}
			
			range = p[i].getRange();
			
			for(int j=0; j<range.length; j++)
			{
				if(!range[j].getName().equals("http://www.w3.org/2000/10/XMLSchema#String"))
				{
					getGraph().add(
						new RdfsRange(
							((RdfsGraph)getGraph()).getNode(p[i]),
							((RdfsGraph)getGraph()).getNode(range[j])
						)
					);
				}
			}
		}
	}
}
