//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI.RDFS;

import java.awt.*;
import javax.swing.*;
import ch.hearc.I04_05s08.GUI.*;
import ch.hearc.I04_05s08.GUI.Graph.*;
import ch.hearc.I04_05s08.GUI.RDFS.*;
import ch.hearc.I04_05s08.Ontology.RDFS.*;

/**
 *	RDFS toolbar
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public class RdfsToolBar extends ToolBar
{	
	/**
	 *	Buttons
	 */
	private JButton[] btns;
	
	/**
	 *	Icons
	 */
	private Icon[] icons;
	
	/**
	 *	Position of the class element
	 */
	private static int iClass = 0;
	
	/**
	 *	Position of the property element
	 */
	private static int iProperty = iClass + 1;
		
	/**
	 *	Position of the extend element
	 */
	private static int iExtend = iProperty + 1;
	
	/**
	 *	Position of the domain element
	 */
	private static int iDomain = iExtend + 1;
	
	/**
	 *	Position of the range element
	 */
	private static int iRange = iDomain + 1;
	
	/**
	 *	Build the RDF toolbar
	 */
	public RdfsToolBar()
	{
		super();
		
		setLayout(new BorderLayout());
		
		JPanel pc = new JPanel();
		JPanel pn = new JPanel();
		
		icons = new Icon[iRange + 1];
		btns = new JButton[iRange + 1];
		
		// Color
		pc.setBackground(Color.white);
		pn.setBackground(Color.white);
		
		init(pn);
		//Dimension d = new Dimension((int)pn.getPreferredSize().getWidth() + 50,(int)pn.getPreferredSize().getHeight());
		//setPreferredSize(d);
		
		pc.add(pn);
		JScrollPane sp = new JScrollPane(pc);
		add(sp);
	}
	
	/**
	 *	Init the icons and buttons
	 *
	 *	@param panel		JPanel containing the buttons
	 */
	private void init(JPanel panel)
	{
		panel.setLayout(new GridLayout(iRange+1,1,0,2));
		
		icons[iClass] = (Icon)new ImageIcon("img/class.png");
		icons[iProperty] = (Icon)new ImageIcon("img/property.png");
		icons[iExtend] = (Icon)new ImageIcon("img/extend.png");
		icons[iDomain] = (Icon)new ImageIcon("img/domain.png");
		icons[iRange] = (Icon)new ImageIcon("img/range.png");
		
		//btns[iClass] = new JButton("Class", icons[iClass]);
		btns[iClass] = new RdfsToolButton("Class", icons[iClass], GraphPanel.NODE_MODE, new RdfsClassNode(new RdfsClass("http://www.example.org/Class","Class")));
		btns[iProperty] = new RdfsToolButton("Property", icons[iProperty], GraphPanel.NODE_MODE, new RdfsPropertyNode(new RdfsProperty("http://www.example.org/Property","Property")));
		btns[iExtend] = new RdfsToolButton("extend", icons[iExtend], GraphPanel.ARROW_MODE, new RdfsExtend());
		btns[iDomain] = new RdfsToolButton("domain", icons[iDomain], GraphPanel.ARROW_MODE, new RdfsDomain());
		btns[iRange] = new RdfsToolButton("range", icons[iRange], GraphPanel.ARROW_MODE, new RdfsRange());
		
		panel.add(btns[iClass]);
		panel.add(btns[iProperty]);
		panel.add(btns[iExtend]);
		panel.add(btns[iDomain]);
		panel.add(btns[iRange]);
	}
	
	/**
	 *	Get the buttons
	 *
	 *	@return the buttons
	 */
	public JButton[] getButtons()
	{
		return btns;
	}
	
	/**
	 *	Get the class button
	 *
	 *	@return Class button
	 */
	public JButton getClassButton()
	{
		return btns[iClass];
	}
	
	/**
	 *	Get the property button
	 *
	 *	@return Property button
	 */
	public JButton getPropertyButton()
	{
		return btns[iProperty];
	}
	
	/**
	 *	Get the extend button
	 *
	 *	@return Extend button
	 */
	public JButton getExtendButton()
	{
		return btns[iExtend];
	}
	
	/**
	 *	Get the domain button
	 *
	 *	@return Domain button
	 */
	public JButton getDomainButton()
	{
		return btns[iDomain];
	}
	
	/**
	 *	Get the Range button
	 *
	 *	@return Range button
	 */
	public JButton getRangeButton()
	{
		return btns[iRange];
	}
}
