//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI;

import javax.swing.filechooser.*;
import java.io.File;

/**
 *	A file filter for file selector
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public class SimpleFileFilter extends FileFilter
{
	/**
	 *	Description
	 */
	private String description;
	
	/**
	 *	Extension
	 */
	private String extension;
	
	/**
	 *	Build filter
	 *
	 *	@param description		the description of the filter
	 */
	public SimpleFileFilter(String description)
	{
		setDescription(description);
	}
	
	/**
	 *	Build the filter
	 */
	public SimpleFileFilter()
	{
		this(null);
	}
	
	/**
	 *	Add an extension
	 *
	 *	@param extension
	 */
	public void addExtension(String extension)
	{
		if(this.extension == null)
			this.extension = extension;
		else
			this.extension += ", " + extension;
	}
	
	public boolean accept(File f)
	{
		if (f.isDirectory()) {
			return true;
		}
	
		String ext = getExtension(f);
		
		return (ext != null && extension.matches(".*"+ext+".*"));
	}
	
	/**
	 *	Set the description of the filter
	 *
	 *	@param description		the description of the filter
	 */
	public void setDescription(String description)
	{
		this.description = description;
	} 
	
	/**
	 *	Get the description of the filter
	 *
	 *	@return the description of the filter
	 */
	public String getDescription()
	{
		return description + " ("+extension+")";
	}
	
	/**
	 *	Get the extension of a file
	 *
	 *	@param f		the file
	 *	@return the extension
	 */
	private String getExtension(File f)
	{
		String ext = null;
		String filename = f.getName();
		
		int index = filename.lastIndexOf('.');
		
		if(index > 0 && index < filename.length() -1)
		{
			ext = filename.substring(index+1).toLowerCase();
		}
		
		return ext;
	}
}
